# RecipeMD

A [standard format](https://recipemd.org/specification.html) for recipes as [Markdown](https://commonmark.org) files 
and a [python reference implementation](https://recipemd.org/reference_implementation.html). The reference 
implementation can be used as a [CLI program](https://recipemd.org/cli.html) and as a 
[python library](https://recipemd.org/_apidoc/recipemd.html).

More info on our website: [recipemd.org](https://recipemd.org)

<p>&nbsp;</p>

<a href="https://recipemd.org/"><img src="https://raw.githubusercontent.com/tstehr/RecipeMD/master/logo/recipemd-mark.png" style="float:right; margin-left:5em"></a>

## License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as 
published by the Free Software Foundation, either version 3 of the 
License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program. If not, see https://www.gnu.org/licenses/.